@@ -8,4 +8,8 @@ class InvalidUser(Exception):
 
 class InvalidProjectID(Exception):
     #Project ID does not exist
+    pass
+
+class Unathourized(Exception):
+    #Unauthourized to do action
     pass
\ No newline at end of file
